@@ -27,6 +27,10 @@ App::Greple::tee - модуль для замены совпадающего т
 
 Строки входных и выходных данных не должны быть одинаковыми при использовании опции B<--discrete>.
 
+=head1 VERSION
+
+Version 0.9901
+
 =head1 OPTIONS
 
 =over 7
@@ -35,6 +39,24 @@ App::Greple::tee - модуль для замены совпадающего т
 
 Вызвать новую команду индивидуально для каждой сопоставленной детали.
 
+=item B<--fillup>
+
+Объедините последовательность непустых строк в одну строку перед передачей их команде фильтра. Символы новой строки между широкими символами удаляются, а другие символы новой строки заменяются пробелами.
+
+=item B<--blockmatch>
+
+Обычно внешней команде передается область, соответствующая заданному шаблону поиска. При указании этой опции будет обрабатываться не совпадающая область, а весь блок, содержащий ее.
+
+Например, чтобы отправить внешней команде строки, содержащие шаблон C<foo>, необходимо указать шаблон, соответствующий всей строке:
+
+    greple -Mtee cat -n -- '^.*foo.*\n'
+
+Но с помощью опции B<--blockmatch> это можно сделать следующим образом:
+
+    greple -Mtee cat -n -- foo
+
+С опцией B<--blockmatch> этот модуль ведет себя подобно опции B<-g> в L<teip(1)>.
+
 =back
 
 =head1 WHY DO NOT USE TEIP
@@ -53,11 +75,7 @@ App::Greple::tee - модуль для замены совпадающего т
 
 Вы можете перевести их с помощью сервиса DeepL, выполнив приведенную выше команду, соединенную с модулем B<-Mtee>, который вызывает команду B<deepl> следующим образом:
 
-    greple -Mtee deepl text --to JA - -- --discrete ...
-
-Поскольку B<deepl> лучше работает для однострочного ввода, вы можете изменить часть команды следующим образом:
-
-    sh -c 'perl -00pE "s/\s+/ /g" | deepl text --to JA -'
+    greple -Mtee deepl text --to JA - -- --fillup ...
 
 Однако для этой цели более эффективен специализированный модуль L<App::Greple::xlate::deepl>. Фактически, подсказка для реализации модуля B<tee> пришла из модуля B<xlate>.
 
@@ -87,7 +105,25 @@ App::Greple::tee - модуль для замены совпадающего т
       b) accompany the distribution with the
          machine-readable source of the
          Package with your modifications.
-    
+
+Использование опции C<--discrete> отнимает много времени. Поэтому вы можете использовать опцию C<--separate '\r'> вместе с C<ansifold>, которая создает одну строку, используя символ CR вместо NL.
+
+    greple -Mtee ansifold -rsw40 --prefix '     ' --separate '\r' --
+
+Затем преобразуйте символ CR в NL с помощью команды L<tr(1)> или другой.
+
+    ... | tr '\r' '\n'
+
+=head1 EXAMPLE 3
+
+Рассмотрим ситуацию, когда вы хотите искать строки в строках, не относящихся к заголовкам. Например, вы можете захотеть найти изображения из команды C<docker image ls>, но оставить строку заголовка. Это можно сделать с помощью следующей команды.
+
+    greple -Mtee grep perl -- -Mline -L 2: --discrete --all
+
+Опция C<-Mline -L 2:> извлекает предпоследние строки и отправляет их команде C<grep perl>. Опция C<--discrete> необходима, но она вызывается только один раз, поэтому недостатка в производительности нет.
+
+В данном случае команда C<teip -l 2- -- grep> выдает ошибку, так как количество строк на выходе меньше, чем на входе. Однако результат вполне удовлетворительный :)
+
 =head1 INSTALL
 
 =head2 CPANMINUS
@@ -106,6 +142,10 @@ L<https://github.com/tecolicom/Greple>
 
 L<App::Greple::xlate>
 
+=head1 BUGS
+
+Опция C<--fillup> может работать некорректно для корейского текста.
+
 =head1 AUTHOR
 
 Kazumasa Utashiro
@@ -121,7 +161,7 @@ it under the same terms as Perl itself.
 
 package App::Greple::tee;
 
-our $VERSION = "0.03";
+our $VERSION = "0.9901";
 
 use v5.14;
 use warnings;
@@ -134,13 +174,13 @@ use Data::Dumper;
 our $command;
 our $blockmatch;
 our $discrete;
+our $fillup;
 
-my @jammed;
 my($mod, $argv);
 
 sub initialize {
     ($mod, $argv) = @_;
-    if (defined (my $i = first { $argv->[$_] eq '--' } 0 .. $#{$argv})) {
+    if (defined (my $i = first { $argv->[$_] eq '--' } keys @$argv)) {
 	if (my @command = splice @$argv, 0, $i) {
 	    $command = \@command;
 	}
@@ -148,18 +188,30 @@ sub initialize {
     }
 }
 
+use Unicode::EastAsianWidth;
+
+sub fillup_paragraph {
+    (my $s1, local $_, my $s2) = $_[0] =~ /\A(\s*)(.*?)(\s*)\z/s or die;
+    s/(?<=\p{InFullwidth})\n(?=\p{InFullwidth})//g;
+    s/\s+/ /g;
+    $s1 . $_ . $s2;
+}
+
 sub call {
     my $data = shift;
     $command // return $data;
     state $exec = App::cdif::Command->new;
+    if ($fillup) {
+	$data =~ s/^.+(?:\n.+)*/fillup_paragraph(${^MATCH})/pmge;
+    }
     if (ref $command ne 'ARRAY') {
 	$command = [ shellwords $command ];
     }
-    $exec->command($command)->setstdin($data)->update->data;
+    $exec->command($command)->setstdin($data)->update->data // '';
 }
 
 sub jammed_call {
-    my @need_nl = grep { $_[$_] !~ /\n\z/ } 0 .. $#_;
+    my @need_nl = grep { $_[$_] !~ /\n\z/ } keys @_;
     my @from = @_;
     $from[$_] .= "\n" for @need_nl;
     my @lines = map { int tr/\n/\n/ } @from;
@@ -174,18 +226,20 @@ sub jammed_call {
     return @to;
 }
 
+my @jammed;
+
 sub postgrep {
     my $grep = shift;
-    @jammed = my @block = ();
     if ($blockmatch) {
 	$grep->{RESULT} = [
 	    [ [ 0, length ],
 	      map {
-		  [ $_->[0][0], $_->[0][1], 0, $grep->{callback} ]
+		  [ $_->[0][0], $_->[0][1], 0, $grep->{callback}->[0] ]
 	      } $grep->result
 	    ] ];
     }
     return if $discrete;
+    @jammed = my @block = ();
     for my $r ($grep->result) {
 	my($b, @match) = @$r;
 	for my $m (@match) {
@@ -210,6 +264,7 @@ __DATA__
 
 builtin --blockmatch $blockmatch
 builtin --discrete!  $discrete
+builtin --fillup!    $fillup
 
 option default \
 	--postgrep &__PACKAGE__::postgrep \
